# gistbin
Github Gist client allowing for quick uploads via commandline. In theory will work like [haste-client](https://github.com/seejohnrun/haste-client).

## To Do
- ~~Get simple version up and running~~
- ~~create script so it can easily be called from command line~~
- ~~create `setup.py` so it can be installed via `pip install`~~
- create PyPi page for it so people can install it
- make it work on Windows and Mac

